# 

School Bus RESTful API Client Python Library is a repository of
classes that provide Pythonic interfaces to the School Bus RESTful Web
services.

This library requires:

* School Bus Common Python Library
* Perseus Common Python Library
* Perseus RESTful API Client Python Library
